@@ -1,5 +1,3 @@
-import numpy
-
 
 class TestDescription(object):
     def test_description(self, monetdbe_cursor):
@@ -9,4 +7,4 @@ class TestDescription(object):
     def test_description_fields(self, monetdbe_cursor):
         monetdbe_cursor.execute('select name from sys.tables')
         assert monetdbe_cursor.description[0][0] == "name"
-        assert monetdbe_cursor.description[0][1] == numpy.dtype('O')
+        assert monetdbe_cursor.description[0][1] == "string"
